@@ -80,7 +80,7 @@ function(orderId,action="BUY",
                  clientId=clientId,
                  permId=permId,
                  action=action,
-                 totalQuantity=as.character(totalQuantity),
+                 totalQuantity=as.character(as.numeric(totalQuantity)),
                  orderType=orderType,
                  lmtPrice=as.character(lmtPrice),
                  auxPrice=as.character(auxPrice),
